#
# spec file for package python-jdatetime
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jdatetime
Version:        5.0.0
Release:        1.1
Summary:        Jalali datetime binding for python
License:        Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/slashmili/python-jalali
Source:         https://github.com/slashmili/python-jalali/archive/v%{version}.tar.gz
BuildRequires:  %{python_module jalali-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytzdata}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  glibc-locale
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-jalali-core
%python_subpackages

%description
jdatetime is the Jalali implementation of Python's datetime module.

%prep
%setup -q -n python-jalali-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m unittest discover tests -v

%files %{python_files}
%doc README.rst CHANGELOG.md
%license LICENSE
%{python_sitelib}/jdatetime
%{python_sitelib}/jdatetime-%{version}.dist-info

%changelog
* Wed Oct 30 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.0:
  * Add support for Python 3.12
  * BREAKING CHANGE: Arithmetic operations on `date`/`datetime`
    against an unknown type will now return `NotImplemented`
    instead of raising `TypeError`
  * Drop Python 3.7 support
  * Move jalali.py to jalali_core dependency due to licensing
    issues #148
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  * Add `fromisoformat` method to `jdatetime.date`
  * Add support for Python 3.11
  * Fix two chars month handling in jdatetime.datetime.strptime
* Thu Jun 23 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 4.1.0
  * Add support for %%z directive in ``jdatetime.datetime.strptime`
  * Add support for %%b and %%B directive directive in ``jdatetime.datetime.strptime`
  Changed
  * Potential breaking change: Replace spaces with ZWNJ (نیم‌فاصله) in output of ``jdatetime.datetime.strftime`
- Update to 4.0.0:
  * Add fold attribute to jdatetime.datetime
  * Change
  * Drop Python < 3.7 support
* Thu Jan 27 2022 Dirk Müller <dmueller@suse.com>
- update to 3.8.2:
  * Fix older version objects unpickling problem
  * Fixed pickle problem of jdate and jdatetime objects(#108)
  * Fixed unicode literal problem in isoformat
  * Add ZoneInfo support
  * Add date.min based on cpython implementation
  * Add date.max based on cpython implementation
  * Run test and publish package from github action
* Mon Mar  2 2020 Steve Kowalik <steven.kowalik@suse.com>
-  Update to version 3.6.2:
  * Support for python 3.7 and 3.8
  * Fixed %%Y length in strptime
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Use upstream description.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.6.0:
  * improve fromgregorian to handle date and datetime input in Pythonic way
  * Adds support for '%%-I' format token
  * support subtraction with python datetime
  * add isoformat for jdatetime.datetime
* Wed Apr  3 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v3.2.0
